@@ -5,7 +5,7 @@ package App::SpeedTest;
 use strict;
 use warnings;
 
-our $VERSION = "0.25";
+our $VERSION = "0.26";
 
 1;
 __END__
@@ -254,12 +254,18 @@ Generate the measurements in XML suited for PRTG
      </result>
    </prtg>
 
-=item --url=XXX
+=item --url[=XXX]
 X<--url>
 
+With no value, show server url in list
+
+With value, use specific server url: do not scan available servers
+
 =item --ip
 X<--ip>
 
+Show IP for server
+
 =item -T[#] | --try[=#]
 X<-T>
 X<--try>
@@ -305,7 +311,7 @@ X<--server>
 
 Specify the ID of the server to test against. This ID can be taken from the
 output of L</--list> or L</--ping>. Using this option prevents fetching the
-complete server list and calculation of distances. It also enables you to
+complete server list and calculation of distances.  It also enables you to
 always test against the same server.
 
  $ speedtest -1s4358
@@ -315,9 +321,32 @@ always test against the same server.
  Test upload   ........................................Upload:     92.552 Mbit/s
  DL:   92.633 Mbit/s, UL:   92.552 Mbit/s
 
+This argument may be repeated to test against multile servers,  more or less
+like specifying your own top x (as with C<-T>).
+
+ $ speedtest -s 22400 -s 1208 -s 13218
+ Testing for 185.x.y.z : Freedom Internet BV ()
+
+ Using 13218:  80.15 km      32 ms XS4ALL Internet BV
+ Test download ........................................Download    66.833 Mbit/s
+ Test upload   ........................................Upload     173.317 Mbit/s
+
+ Using  1208:  51.19 km      37 ms Qweb | Full-Service Hosting
+ Test download ........................................Download    52.077 Mbit/s
+ Test upload   ........................................Upload     195.833 Mbit/s
+
+ Using 22400:  80.15 km      46 ms Usenet.Farm
+ Test download ........................................Download    96.341 Mbit/s
+ Test upload   ........................................Upload     203.306 Mbit/s
+
+ Rank 01: Server:  22400   80.15 km      46 ms,  DL:   96.341 UL:  203.306
+ Rank 02: Server:   1208   51.19 km      37 ms,  DL:   52.077 UL:  195.833
+ Rank 03: Server:  13218   80.15 km      32 ms,  DL:   66.833 UL:  173.317
+
 If you pass a filename, it is expected to reflect a server-like structure as
 received from the speedtest server-list, possibly completed with upload- and
-download URL's:
+download URL's. You can only pass one filename not consisting of all digits.
+If you do, all remaining C<-s> arguments are ignored.
 
   {   cc      => "NL",
       country => "Netherlands",
@@ -459,13 +488,13 @@ I really don't care about mixed spaces and tabs in (leading) whitespace
 
 =head1 WARRANTY
 
-This tool is by no means a guarantee to show the correc6t speeds. It
+This tool is by no means a guarantee to show the correct speeds. It
 is only to be used as an indication of the throughput of your internet
 connection. The values shown cannot be used in a legal debate.
 
 =head1 AUTHOR
 
-H.Merijn Brand F<E<lt>h.m.brand@xs4all.nlE<gt>> wrote this for his own
+H.Merijn Brand F<E<lt>linux@tux.freedom.nlE<gt>> wrote this for his own
 personal use, but was asked to make it publicly available as application.
 
 =head1 COPYRIGHT AND LICENSE
